@@ -1,4 +1,4 @@
-"""Functions for computing atomic structure of proteins"""
+"""Functions for computing atomic structure of proteins."""
 import logging
 
 # %%
@@ -30,13 +30,18 @@ log = logging.getLogger(__name__)
 
 def assign_bond_states_to_dataframe(df: pd.DataFrame) -> pd.DataFrame:
     """
-    Takes a PandasPDB atom dataframe and assigns bond states to each atom based on:
-    Atomic Structures of all the Twenty Essential Amino Acids and a Tripeptide, with Bond Lengths as Sums of Atomic Covalent Radii
-    Heyrovska, 2008
+    Takes a ``PandasPDB`` atom dataframe and assigns bond states to each atom based on:
+
+        Atomic Structures of all the Twenty Essential Amino Acids and a Tripeptide, with Bond Lengths as Sums of Atomic Covalent Radii
+        Heyrovska, 2008
+
+    First, maps atoms to their standard bond states (:const:`~graphein.protein.resi_atoms.DEFAULT_BOND_STATE`).
+    Second, maps non-standard bonds states (:const:`~graphein.protein.resi_atoms.RESIDUE_ATOM_BOND_STATE`).
+    Fills NaNs with standard bond states.
 
     :param df: Pandas PDB dataframe
     :type df: pd.DataFrame
-    :return: Dataframe with added atom_bond_state column
+    :return: Dataframe with added ``atom_bond_state`` column
     :rtype: pd.DataFrame
     """
 
@@ -62,13 +67,14 @@ def assign_bond_states_to_dataframe(df: pd.DataFrame) -> pd.DataFrame:
 
 def assign_covalent_radii_to_dataframe(df: pd.DataFrame) -> pd.DataFrame:
     """
-    Assigns covalent radius to each atom based on its bond state. Using Values from :
-    Atomic Structures of all the Twenty Essential Amino Acids and a Tripeptide, with Bond Lengths as Sums of Atomic Covalent Radii
-    Heyrovska, 2008
+    Assigns covalent radius (:const:`~graphein.protein.resi_atoms.COVALENT_RADII`) to each atom based on its bond state. Adds a ``covalent_radius`` column. Using values from:
 
-    :param df: Pandas PDB dataframe with a bond_states_column
+        Atomic Structures of all the Twenty Essential Amino Acids and a Tripeptide, with Bond Lengths as Sums of Atomic Covalent Radii
+        Heyrovska, 2008
+
+    :param df: Pandas PDB dataframe with a ``bond_states_column``
     :type df: pd.DataFrame
-    :return: Pandas PDB dataframe with added covalent_radius column
+    :return: Pandas PDB dataframe with added ``covalent_radius`` column
     :rtype: pd.DataFrame
     """
     # Assign covalent radius to each atom
@@ -77,18 +83,19 @@ def assign_covalent_radii_to_dataframe(df: pd.DataFrame) -> pd.DataFrame:
     return df
 
 
-def add_atomic_edges(G: nx.Graph) -> nx.Graph:
+def add_atomic_edges(G: nx.Graph, tolerance: float = 0.56) -> nx.Graph:
     """
-    Computes covalent edges based on atomic distances. Covalent radii add_atomic_edges assigned to each atom based on its bond assign_bond_states_to_dataframe
-    The distance matrix is then thresholded to entries less than this distance plus some tolerance to create and adjacency matrix.
+    Computes covalent edges based on atomic distances. Covalent radii are assigned to each atom based on its bond assign_bond_states_to_dataframe
+    The distance matrix is then thresholded to entries less than this distance plus some tolerance to create an adjacency matrix.
     This adjacency matrix is then parsed into an edge list and covalent edges added
 
     :param G: Atomic graph (nodes correspond to atoms) to populate with atomic bonds as edges
     :type G: nx.Graph
+    :param tolerance: Tolerance for atomic distance. Default is ``0.56`` Angstroms. Commonly used values are: ``0.4, 0.45, 0.56``
+    :type tolerance: float
     :return: Atomic graph with edges between bonded atoms added
     :rtype: nx.Graph
     """
-    TOLERANCE = 0.56  # 0.4 0.45, 0.56 This is the distance tolerance
     dist_mat = compute_distmat(G.graph["pdb_df"])
 
     # We assign bond states to the dataframe, and then map these to covalent radii
@@ -103,7 +110,7 @@ def add_atomic_edges(G: nx.Graph) -> nx.Graph:
 
     # Add the tolerance
     covalent_radius_distance_matrix = (
-        covalent_radius_distance_matrix + TOLERANCE
+        covalent_radius_distance_matrix + tolerance
     )
 
     # Threshold Distance Matrix to entries where the eucl distance is less than the covalent radius plus tolerance and larger than 0.4
@@ -143,12 +150,12 @@ def add_atomic_edges(G: nx.Graph) -> nx.Graph:
 
 def add_ring_status(G: nx.Graph) -> nx.Graph:
     """
-    Identifies rings in the atomic graph. Assigns the edge attribute "RING" to edges in the ring. We do not distinguish
-    between aromatic and non aromatic rings.
+    Identifies rings in the atomic graph. Assigns the edge attribute ``"RING"`` to edges in the ring. We do not distinguish
+    between aromatic and non-aromatic rings. Functions by identifying all cycles in the graph.
 
     :param G: Atom-level protein structure graph to add ring edge types to
     :type G: nx.Graph
-    :return: Atom-level protein structure graph with added RING edge attribute
+    :return: Atom-level protein structure graph with added ``"RING"`` edge attribute
     :rtype: nx.Graph
     """
     cycles = nx.cycle_basis(
@@ -170,8 +177,9 @@ def add_ring_status(G: nx.Graph) -> nx.Graph:
 def add_bond_order(G: nx.Graph) -> nx.Graph:
     """
     Assign bond orders to the covalent bond edges between atoms on the basis of bond length. Values are taken from:
-    Automatic Assignment of Chemical Connectivity to Organic Molecules in the CambridgeStructural Database.
-    Jon C. Baber and Edward E. Hodgkin*
+
+        Automatic Assignment of Chemical Connectivity to Organic Molecules in the Cambridge Structural Database.
+        Jon C. Baber and Edward E. Hodgkin*
 
     :param G: Atomic-level protein graph with covalent edges.
     :type G: nx.Graph
@@ -210,14 +218,15 @@ def identify_bond_type_from_mapping(
     """
     Compares the bond length between two atoms in the graph, and the relevant experimental value by performing a lookup
     against the watershed values in:
-    Automatic Assignment of Chemical Connectivity to Organic Molecules in the Cambridge
-    Structural Database. Jon C. Baber and Edward E. Hodgkin*
 
-    Bond orders are assigned in the order triple < double < single (e.g. if a bond is shorter than the triple bond
-    watershed (w_dt) then it is assigned as a triple bond. Similarly, if a bond is longer than this but shorter than the
-    double bond watershed, it is assigned double bond status.
+        Automatic Assignment of Chemical Connectivity to Organic Molecules in the Cambridge
+        Structural Database. Jon C. Baber and Edward E. Hodgkin*
 
-    :param G: nx.Graph of atom-protein structure with atomic edges added
+    Bond orders are assigned in the order ``triple`` < ``double`` < ``single`` (e.g. if a bond is shorter than the triple bond
+    watershed (``w_dt``) then it is assigned as a triple bond. Similarly, if a bond is longer than this but shorter than the
+    double bond watershed (``w_sd``), it is assigned double bond status.
+
+    :param G: ``nx.Graph`` of atom-protein structure with atomic edges added
     :type G: nx.Graph
     :param u: node 1 in edge
     :type u: str
@@ -225,7 +234,7 @@ def identify_bond_type_from_mapping(
     :type v: str
     :param a: edge data
     :type a: Dict[str, Any]
-    :param query: "ELEMENTX-ELEMENTY" to perform lookup with (E.g. C-O, N-N)
+    :param query: ``"ELEMENTX-ELEMENTY"`` to perform lookup with (E.g. ``"C-O"``,``"N-N"``)
     :type query: str
     :return: Graph with atomic edge bond order assigned
     :rtype: nx.Graph
