@@ -21,13 +21,23 @@ from .resi_atoms import RESI_THREE_TO_1
 log = logging.getLogger(__name__)
 
 
+class ProteinGraphConfigurationError(Exception):
+    """Exception when an invalid Graph configuration if provided to a downstream function or method."""
+
+    def __init__(self, message: str):
+        self.message = message
+
+    def __str__(self):
+        return self.message
+
+
 def download_pdb(config, pdb_code: str) -> Path:
     """
-    Download PDB structure from PDB
+    Download PDB structure from PDB.
 
-    :param pdb_code: 4 character PDB accession code
+    :param pdb_code: 4 character PDB accession code.
     :type pdb_code: str
-    :return: returns filepath to downloaded structure
+    :return: returns filepath to downloaded structure.
     :rtype: str
     """
     if not config.pdb_dir:
@@ -40,22 +50,23 @@ def download_pdb(config, pdb_code: str) -> Path:
     )
     # Rename file to .pdb from .ent
     os.rename(
-        config.pdb_dir / ("pdb" + pdb_code + ".ent"),
-        config.pdb_dir / (pdb_code + ".pdb"),
+        config.pdb_dir / f"pdb{pdb_code}.ent",
+        config.pdb_dir / f"{pdb_code}.pdb",
     )
+
     # Assert file has been downloaded
     assert any(pdb_code in s for s in os.listdir(config.pdb_dir))
     log.info(f"Downloaded PDB file for: {pdb_code}")
-    return config.pdb_dir / (pdb_code + ".pdb")
+    return config.pdb_dir / f"{pdb_code}.pdb"
 
 
 def get_protein_name_from_filename(pdb_path: str) -> str:
     """
-    Extracts a filename from a pdb_path
+    Extracts a filename from a ``pdb_path``
 
-    :param pdb_path: Path to extract filename from
+    :param pdb_path: Path to extract filename from.
     :type pdb_path: str
-    :return: file name
+    :return: file name.
     :rtype: str
     """
     _, tail = os.path.split(pdb_path)
@@ -71,19 +82,20 @@ def filter_dataframe(
 ) -> pd.DataFrame:
     """
     Filter function for dataframe.
-    Filters the [dataframe] such that the [by_column] values have to be
-    in the [list_of_values] list if boolean == True, or not in the list
-    if boolean == False
 
-    :param dataframe: pd.DataFrame to filter
+    Filters the dataframe such that the ``by_column`` values have to be
+    in the ``list_of_values`` list if ``boolean == True``, or not in the list
+    if ``boolean == False``.
+
+    :param dataframe: pd.DataFrame to filter.
     :type dataframe: pd.DataFrame
-    :param by_column: str denoting by_column of dataframe to filter
+    :param by_column: str denoting column of dataframe to filter.
     :type by_column: str
-    :param list_of_values: List of values to filter with
+    :param list_of_values: List of values to filter with.
     :type list_of_values: List[Any]
-    :param boolean: indicates whether to keep or exclude matching list_of_values. True -> in list, false -> not in list
+    :param boolean: indicates whether to keep or exclude matching ``list_of_values``. ``True`` -> in list, ``False`` -> not in list.
     :type boolean: bool
-    :returns: Filtered dataframe
+    :returns: Filtered dataframe.
     :rtype: pd.DataFrame
     """
     df = dataframe.copy()
@@ -102,15 +114,15 @@ def download_alphafold_structure(
 ) -> Union[str, Tuple[str, str]]:
     BASE_URL = "https://alphafold.ebi.ac.uk/files/"
     """
-    Downloads a structure from the Alphafold EBI database.
+    Downloads a structure from the Alphafold EBI database (https://alphafold.ebi.ac.uk/files/").
 
-    :param uniprot_id: UniProt ID of desired protein
+    :param uniprot_id: UniProt ID of desired protein.
     :type uniprot_id: str
-    :param out_dir: string specifying desired output location. Default is pwd.
+    :param out_dir: String specifying desired output location. Default is pwd.
     :type out_dir: str
-    :param mmcif: Bool specifying whether to download MMCiF or PDB. Default is false (downloads pdb)
+    :param mmcif: Bool specifying whether to download ``MMCiF`` or ``PDB``. Default is ``False`` (downloads pdb).
     :type mmcif: bool
-    :param retrieve_aligned_score: Bool specifying whether or not to download score alignment json
+    :param retrieve_aligned_score: Bool specifying whether or not to download score alignment json.
     :type retrieve_aligned_score: bool
     :return: path to output. Tuple if several outputs specified.
     :rtype: Union[str, Tuple[str, str]]
@@ -118,9 +130,9 @@ def download_alphafold_structure(
     if not mmcif and not pdb:
         raise ValueError("Must specify either mmcif or pdb.")
     if mmcif:
-        query_url = BASE_URL + "AF-" + uniprot_id + "F1-model_v1.cif"
+        query_url = f"{BASE_URL}AF-{uniprot_id}F1-model_v1.cif"
     if pdb:
-        query_url = BASE_URL + "AF-" + uniprot_id + "-F1-model_v1.pdb"
+        query_url = f"{BASE_URL}AF-{uniprot_id}-F1-model_v1.pdb"
 
     structure_filename = wget.download(query_url, out=out_dir)
 
@@ -141,9 +153,11 @@ def three_to_one_with_mods(res: str) -> str:
     """
     Converts three letter AA codes into 1 letter. Allows for modified residues.
 
-    :param res: Three letter residue code str:
+    See: :const:`~graphein.protein.resi_atoms.RESI_THREE_TO_1`.
+
+    :param res: Three letter residue code string.
     :type res: str
-    :return: 1-letter residue code
+    :return: 1-letter residue code.
     :rtype: str
     """
     return RESI_THREE_TO_1[res]
